Module: Google::Cloud::VectorSearch

Defined in:
lib/google/cloud/vector_search.rb,
lib/google/cloud/vector_search/version.rb

Constant Summary collapse

VERSION =
"0.1.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.vector_search| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-vector_search library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



291
292
293
294
295
# File 'lib/google/cloud/vector_search.rb', line 291

def self.configure
  yield ::Google::Cloud.configure.vector_search if block_given?

  ::Google::Cloud.configure.vector_search
end

.data_object_search_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataObjectSearchService.

By default, this returns an instance of Google::Cloud::VectorSearch::V1::DataObjectSearchService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataObjectSearchService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataObjectSearchService service. You can determine whether the method will succeed by calling data_object_search_service_available?.

About DataObjectSearchService

Service for searching data objects.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



75
76
77
78
79
80
81
82
83
84
85
# File 'lib/google/cloud/vector_search.rb', line 75

def self.data_object_search_service version: :v1, transport: :grpc, &block
  require "google/cloud/vector_search/#{version.to_s.downcase}"

  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::VectorSearch.const_get(package_name).const_get(:DataObjectSearchService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.data_object_search_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataObjectSearchService service is supported by the current client. If true, you can retrieve a client object by calling data_object_search_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataObjectSearchService service, or if the versioned client gem needs an update to support the DataObjectSearchService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/google/cloud/vector_search.rb', line 99

def self.data_object_search_service_available? version: :v1, transport: :grpc
  require "google/cloud/vector_search/#{version.to_s.downcase}"
  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::VectorSearch.const_get package_name
  return false unless service_module.const_defined? :DataObjectSearchService
  service_module = service_module.const_get :DataObjectSearchService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.data_object_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataObjectService.

By default, this returns an instance of Google::Cloud::VectorSearch::V1::DataObjectService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataObjectService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataObjectService service. You can determine whether the method will succeed by calling data_object_service_available?.

About DataObjectService

Service for creating and managing data objects.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



145
146
147
148
149
150
151
152
153
154
155
# File 'lib/google/cloud/vector_search.rb', line 145

def self.data_object_service version: :v1, transport: :grpc, &block
  require "google/cloud/vector_search/#{version.to_s.downcase}"

  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::VectorSearch.const_get(package_name).const_get(:DataObjectService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.data_object_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataObjectService service is supported by the current client. If true, you can retrieve a client object by calling data_object_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataObjectService service, or if the versioned client gem needs an update to support the DataObjectService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/google/cloud/vector_search.rb', line 169

def self.data_object_service_available? version: :v1, transport: :grpc
  require "google/cloud/vector_search/#{version.to_s.downcase}"
  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::VectorSearch.const_get package_name
  return false unless service_module.const_defined? :DataObjectService
  service_module = service_module.const_get :DataObjectService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.vector_search_service(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for VectorSearchService.

By default, this returns an instance of Google::Cloud::VectorSearch::V1::VectorSearchService::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the VectorSearchService service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the VectorSearchService service. You can determine whether the method will succeed by calling vector_search_service_available?.

About VectorSearchService

VectorSearchService provides methods for managing Collection resources, and Collection Index resources. The primary resources offered by this service are Collections which are a container for a set of related JSON data objects, and Collection Indexes which enable efficient ANN search across data objects within a Collection.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



219
220
221
222
223
224
225
226
227
228
229
# File 'lib/google/cloud/vector_search.rb', line 219

def self.vector_search_service version: :v1, transport: :grpc, &block
  require "google/cloud/vector_search/#{version.to_s.downcase}"

  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::VectorSearch.const_get(package_name).const_get(:VectorSearchService)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.vector_search_service_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the VectorSearchService service is supported by the current client. If true, you can retrieve a client object by calling vector_search_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the VectorSearchService service, or if the versioned client gem needs an update to support the VectorSearchService service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/google/cloud/vector_search.rb', line 243

def self.vector_search_service_available? version: :v1, transport: :grpc
  require "google/cloud/vector_search/#{version.to_s.downcase}"
  package_name = Google::Cloud::VectorSearch
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::VectorSearch.const_get package_name
  return false unless service_module.const_defined? :VectorSearchService
  service_module = service_module.const_get :VectorSearchService
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end